@@ -111,7 +111,13 @@ function(am, start.b, start.siga,dyad.explist,fixedglsopt,dmefglsopt,dmeopt,ctab
     # use existing gls estimate as oldsiga
     oldsiga <- siga
 
-    dme.fgls <- fgls.iter.siga(am, oldsiga, mmat, dyad.explist, evec, dmefglsopt, dmeopt, ctable)
+    if( am$l == 1) {
+      dme.fgls <- fgls.iter.siga.univ(am, oldsiga, mmat, dyad.explist, evec, dmefglsopt, dmeopt, ctable)
+    }
+    else if( am$l > 1 ){
+      dme.fgls <- fgls.iter.siga.multiv(am, siga, mmat, dyad.explist, evec, dmefglsopt, dmeopt, ctable)
+    }
+
     siga <- dme.fgls$siga
 #   cat("Siga fgls:\n")
 #   print(siga)
@@ -294,7 +300,13 @@ function(am, start.b, start.siga,dyad.explist,fixedglsopt,dmefglsopt,dmeopt,ctab
     print(vart)
     # end of ols
 
-    dme.fgls <- fgls.iter.siga(am, oldsiga, mmat, dyad.explist, evec, dmefglsopt, dmeopt, ctable)
+    if( am$l == 1) {
+      dme.fgls <- fgls.iter.siga.univ(am, siga, mmat, dyad.explist, evec, dmefglsopt, dmeopt, ctable)
+    }
+    else if( am$l > 1 ){
+      dme.fgls <- fgls.iter.siga.multiv(am, siga, mmat, dyad.explist, evec, dmefglsopt, dmeopt, ctable)
+    }
+
     siga <- dme.fgls$siga
 #   cat("Siga fgls:\n")
 #   print(siga)
