@@ -103,7 +103,7 @@ function(dmmobj,traitset="all",componentset="all",bytrait=T,fixedgls=F,digits=3,
                          CI95lo=ci95lo,CI95hi=ci95hi)
     ptables[[1]] <- ptable
 
-    retobj <- list(ftables=ftables, rtables=rtables, ptables=ptables, traits=traits, components=components, bytrait=bytrait, fixedgls=fixedgls, digits=digits)
+    retobj <- list(ftables=ftables, rtables=rtables, ptables=ptables, traits=traits, components=components, bytrait=bytrait, fixedgls=fixedgls, digits=digits, dmeopt=dmmobj$dmeopt)
 
     if(fixedgls) {
     if(bytrait) {
@@ -174,7 +174,7 @@ function(dmmobj,traitset="all",componentset="all",bytrait=T,fixedgls=F,digits=3,
                          CI95lo=ci95lo,CI95hi=ci95hi)
     gptables[[1]] <- ptable
   
-    retobj <- list(ftables=ftables,rtables=rtables,ptables=ptables,gftables=gftables,grtables=grtables,gptables=gptables,traits=traits, components=components, bytrait=bytrait, fixedgls=fixedgls, digits=digits)
+    retobj <- list(ftables=ftables,rtables=rtables,ptables=ptables,gftables=gftables,grtables=grtables,gptables=gptables,traits=traits, components=components, bytrait=bytrait, fixedgls=fixedgls, digits=digits, dmeopt=dmmobj$dmeopt)
     }
   
     retobj$call <- match.call()
