@@ -28,7 +28,7 @@ function(dmmobj,traitset,componentset,bytrait,fixedgls,digits,...)
     ic <- ic + 1
   }
   names(csumlist) <- names(dmmobj$specific)
-  retobj <- list(csumlist=csumlist,traits=traits,components=components,bytrait=bytrait,fixedgls=fixedgls,digits=digits)
+  retobj <- list(csumlist=csumlist,traits=traits,components=components,bytrait=bytrait,fixedgls=fixedgls,digits=digits,dmeopt=dmmobj$dmeopt)
 
   if(fixedgls) {
     nc <- length(names(dmmobj$gls$specific))
@@ -39,7 +39,7 @@ function(dmmobj,traitset,componentset,bytrait,fixedgls,digits,...)
       ic <- ic + 1
     }
     names(gcsumlist) <- names(dmmobj$gls$specific)
-    retobj <- list(csumlist=csumlist,gcsumlist=gcsumlist,traits=traits,components=components,bytrait=bytrait,fixedgls=fixedgls,digits=digits)
+    retobj <- list(csumlist=csumlist,gcsumlist=gcsumlist,traits=traits,components=components,bytrait=bytrait,fixedgls=fixedgls,digits=digits,dmeopt=dmmobj$dmeopt)
   }
 
   retobj$call <- match.call()
