@@ -10,7 +10,8 @@ function(x, ...)
     print(x$btables[[i]],digits=x$digits)
     cat("\n")
   }
-  cat("\nComponents partitioned by DME from residual var/covariance after OLS-fixed-effects fit:\n\n")
+  cat("\nComponents partitioned by DME from residual var/covariance after OLS-fixed-effects fit:\n")
+  cat("Dmeopt = ", x$dmeopt, "\n\n")
   for(i in 1:length(x$ctables)) {
     print(x$ctables[[i]],digits=x$digits)
     cat("\n")
@@ -22,7 +23,8 @@ function(x, ...)
       print(x$gbtables[[i]],digits=x$digits)
       cat("\n")
     }
-    cat("\nComponents partitioned by DME from residual var/covariance after GLS-fixed-effects fit:\n\n")
+    cat("\nComponents partitioned by DME from residual var/covariance after GLS-fixed-effects fit:\n")
+    cat("Dmeopt = ", x$dmeopt, "\n\n")
     for(i in 1:length(x$gctables)) {
       print(x$gctables[[i]],digits=x$digits)
       cat("\n")
